%Projekt: RocketSim

%Funktion plot_position
%Werte die Ergebnisse der Differentialgleichung aus
%und stellt sie grafisch dar.

function plot_position(rakete)

%Konstanten
gam = 6.67 * 10^-11;  %Gravitationskonstante
me = 5.9736 * 10^24;  %Erdmasse  /kg
re = 6378130;         %Erdradius /m
mm = 7.348 * 10^22;   %Mondmasse  /kg
rm = 3476000/2;       %Mondradius /m
ma = 384405 * 10^3;   %Erdabstand /m

%Startwerte
if (nargin < 1) || (isempty(rakete))
    rakete.u  = 4500; 
    rakete.dm = 20;
    rakete.m0 = 3700;
    rakete.m0_min = 100;
    %rakete.start_pos = unitsratio('rad', 'deg') *  90;
    %rakete.start_rot = unitsratio('rad', 'deg') * -90.5;
    
    rakete.start_pos = 90 * pi/180;
    rakete.start_rot = -90.5 * pi/180;
    
    rakete.t_ende    = 3*60*60*24;
    rakete.t_schritt = 120;
    rakete.autoflight = 0;
    rakete.h_brems   = 0;
    rakete.v_brems   = 960;
end

rakete.h_brems = ma - rm - rakete.h_brems;

%Brennschluss und Berechnungsschrittweite
rakete.t_brennschluss = ceil((rakete.m0-rakete.m0_min) / rakete.dm);

%Zeitvektor
t = [0:1:rakete.t_brennschluss, rakete.t_brennschluss+1:rakete.t_schritt:rakete.t_ende];

%Drehungswinkel waehrend Startphase
phi_start = 0;
phi_end   = rakete.start_rot;

%Schrittweite fuer Eigendrehung der Rakete
phi_step = (phi_end - phi_start) / rakete.t_brennschluss;

%***********************************************
%Differentialgleichung und sonstige Berechnungen
%***********************************************
[t, pos] = position(t, rakete, gam, me, re, phi_start, phi_step, mm, rm, ma);
[xe, ye] = earth(re);
[xm, ym] = moon(rm, ma);


%*****************************************
%Analyse der Daten 
%*****************************************
s_x = pos(:,1)';
s_y = pos(:,3)';
v_x = pos(:,2)';
v_y = pos(:,4)';

%Brennschlussdaten sammeln
x_brennschluss = pos(rakete.t_brennschluss, 1);
y_brennschluss = pos(rakete.t_brennschluss, 3);

%Resultierende Geschwindigkeit und Hoehe berechnen
v_res = sqrt(v_x.^2 + v_y.^2);
h_res = sqrt(s_x.^2 + s_y.^2);

%***************************
%Plotten
%***************************

%Anpassen der figure
scrsz = get(0,'ScreenSize');
fh = figure('Position',[1 scrsz(4) scrsz(3) scrsz(4)-100]);

%Erster Plot: Erde mit Rakete
subplot(3,2,1:4);
hold on;

axis equal;
set(gca, 'Color', [0 0 0.1]);

xsize = ma+rm*5+re*5;
ysize = re*30;

%Gravitationsfelder plotten
plot_gravitationsfeld(gam, me, re, 0, 0);
plot_gravitationsfeld(gam, mm, rm, ma, 0);

%Planeten
fill(xe, ye, [0.2, 0.2, 1.0]);   %Erde
fill(xm, ym, [1.0, 1.0, 0.3]);   %Mond
drawnow;

%Raketenflugbahn
x_patch = [s_x(1:end-1);   s_x(2:end)];
y_patch = [s_y(1:end-1);   s_y(2:end)];
v_patch = [v_res(1:end-1); v_res(2:end)] ./ max(v_res);
patch(x_patch, y_patch, v_patch, 'EdgeColor', 'interp', 'LineWidth', 1);

%Sterne
%plot(rand(30,1)*xsize-re*5, rand(30,1)*ysize-re*15, 'LineStyle', '*', 'Color', [1.0, 1.0, 0.8]./6);

xlim([-re*5; +ma+rm*6]);

%Brenndauer einzeichnen
text(x_brennschluss, y_brennschluss,'Brennschluss \rightarrow', 'HorizontalAlignment','right', 'Color', 'w', 'FontSize', 8);
title(['Raketenbahn, Brenndauer: ', num2str(rakete.t_brennschluss), ' Sekunden']); 
hold off;

%Zweiter Plot: Geschwindigkeiten
subplot(3,2,5:6);

hold on;
plot(t, v_x, 'g--');  %X-Richtung
plot(t, v_y, 'b--');  %Y-Richtung
plot(t, v_res, 'r-');
set(gca, 'Color', [0.9, 0.9, 0.9]);
title(['Geschwindigkeiten, v bei Brennschluss: ', num2str(v_res(rakete.t_brennschluss)), ' m/s']);
legend('X', 'Y', 'Resultierend', 'Location', 'Best');
hold off;

end